From 039b12f77fdcb1f75a964fbf781dcc57c4a18dee Mon Sep 17 00:00:00 2001
From: Kailang Yang <kailang@realtek.com>
Date: Thu, 20 Nov 2014 14:58:08 +0800
Subject: [PATCH] ALSA: hda/realtek - Supported HP mute Led for ALC286

New HP machine supported output mute led and input mute led.
ALC286:
GPIO1 to control output mute led.
GPIO5 to control input mute led.

Signed-off-by: Kailang Yang <kailang@realtek.com>

diff --git a/sound/pci/hda/patch_realtek.c b/sound/pci/hda/patch_realtek.c
index 8fea1b8..28316f8 100644
--- a/sound/pci/hda/patch_realtek.c
+++ b/sound/pci/hda/patch_realtek.c
@@ -92,6 +92,8 @@ struct alc_spec {
 
 	/* mute LED for HP laptops, see alc269_fixup_mic_mute_hook() */
 	int mute_led_polarity;
+	unsigned int gpio_spk_mute_led_mask;
+	unsigned int gpio_mic_mute_led_mask;
 	hda_nid_t mute_led_nid;
 	hda_nid_t cap_mute_led_nid;
 
@@ -3311,23 +3313,23 @@ static void alc269_fixup_hp_mute_led_mic2(struct hda_codec *codec,
 }
 
 /* turn on/off mute LED per vmaster hook */
-static void alc269_fixup_hp_gpio_mute_hook(void *private_data, int enabled)
+static void alc_fixup_hp_gpio_mute_hook(void *private_data, int enabled)
 {
 	struct hda_codec *codec = private_data;
 	struct alc_spec *spec = codec->spec;
 	unsigned int oldval = spec->gpio_led;
 
 	if (enabled)
-		spec->gpio_led &= ~0x08;
+		spec->gpio_led &= ~spec->gpio_spk_mute_led_mask;
 	else
-		spec->gpio_led |= 0x08;
+		spec->gpio_led |= spec->gpio_spk_mute_led_mask;
 	if (spec->gpio_led != oldval)
 		snd_hda_codec_write(codec, 0x01, 0, AC_VERB_SET_GPIO_DATA,
 				    spec->gpio_led);
 }
 
 /* turn on/off mic-mute LED per capture hook */
-static void alc269_fixup_hp_gpio_mic_mute_hook(struct hda_codec *codec,
+static void alc_fixup_hp_gpio_mic_mute_hook(struct hda_codec *codec,
 					       struct snd_kcontrol *kcontrol,
 					       struct snd_ctl_elem_value *ucontrol)
 {
@@ -3339,9 +3341,9 @@ static void alc269_fixup_hp_gpio_mic_mute_hook(struct hda_codec *codec,
 
 	if (ucontrol->value.integer.value[0] ||
 	    ucontrol->value.integer.value[1])
-		spec->gpio_led &= ~0x10;
+		spec->gpio_led &= ~spec->gpio_mic_mute_led_mask;
 	else
-		spec->gpio_led |= 0x10;
+		spec->gpio_led |= spec->gpio_mic_mute_led_mask;
 	if (spec->gpio_led != oldval)
 		snd_hda_codec_write(codec, 0x01, 0, AC_VERB_SET_GPIO_DATA,
 				    spec->gpio_led);
@@ -3356,10 +3358,30 @@ static void alc269_fixup_hp_gpio_led(struct hda_codec *codec,
 		{ 0x01, AC_VERB_SET_GPIO_DIRECTION, 0x18 },
 		{}
 	};
+	spec->gpio_spk_mute_led_mask = 0x08;
+	spec->gpio_mic_mute_led_mask = 0x10;
+ 	if (action == HDA_FIXUP_ACT_PRE_PROBE) {
+		spec->gen.vmaster_mute.hook = alc_fixup_hp_gpio_mute_hook;
+		spec->gen.cap_sync_hook = alc_fixup_hp_gpio_mic_mute_hook;
+		spec->gpio_led = 0;
+		snd_hda_add_verbs(codec, gpio_init);
+	}
+}
 
-	if (action == HDA_FIXUP_ACT_PRE_PROBE) {
-		spec->gen.vmaster_mute.hook = alc269_fixup_hp_gpio_mute_hook;
-		spec->gen.cap_sync_hook = alc269_fixup_hp_gpio_mic_mute_hook;
+static void alc286_fixup_hp_gpio_led(struct hda_codec *codec,
+				const struct hda_fixup *fix, int action)
+{
+	struct alc_spec *spec = codec->spec;
+	static const struct hda_verb gpio_init[] = {
+		{ 0x01, AC_VERB_SET_GPIO_MASK, 0x22 },
+		{ 0x01, AC_VERB_SET_GPIO_DIRECTION, 0x22 },
+		{}
+	};
+	spec->gpio_spk_mute_led_mask = 0x02;
+	spec->gpio_mic_mute_led_mask = 0x20;
+ 	if (action == HDA_FIXUP_ACT_PRE_PROBE) {
+		spec->gen.vmaster_mute.hook = alc_fixup_hp_gpio_mute_hook;
+		spec->gen.cap_sync_hook = alc_fixup_hp_gpio_mic_mute_hook;
 		spec->gpio_led = 0;
 		snd_hda_add_verbs(codec, gpio_init);
 	}
